@@ -6,7 +6,7 @@ use Furl::HTTP;
 use Furl::Request;
 use Furl::Response;
 use Carp ();
-our $VERSION = '3.07';
+our $VERSION = '3.08';
 
 use 5.008001;
 
@@ -56,11 +56,12 @@ sub put {
 }
 
 sub delete {
-    my ( $self, $url, $headers ) = @_;
+    my ( $self, $url, $headers, $content ) = @_;
     $self->request(
         method  => 'DELETE',
         url     => $url,
-        headers => $headers
+        headers => $headers,
+        content => $content
     );
 }
 
@@ -100,25 +101,6 @@ sub request {
         $args{headers} = $headers;
     }
 
-    my $cookie_jar = ${$self}->{cookie_jar};
-
-    if ($cookie_jar) {
-        my $url;
-        if ($args{url}) {
-            $url = $args{url};
-        } else {
-            $url = join(
-                '',
-                $args{scheme},
-                '://',
-                $args{host},
-                (exists($args{port}) ? ":$args{port}" : ()),
-                exists($args{path_query}) ? $args{path_query} : '/',
-            );
-        }
-        push @{$args{headers}}, 'Cookie' => $cookie_jar->cookie_header($url);
-    }
-
     my (
         $res_minor_version,
         $res_status,
@@ -135,21 +117,6 @@ sub request {
     my $res = Furl::Response->new($res_minor_version, $res_status, $res_msg, $res_headers, $res_content);
     $res->set_request_info(\%args, $captured_req_headers, $captured_req_content);
 
-    if ($cookie_jar) {
-        my ($scheme, $username, $password, $host, $port, $path_query) = @$request_info;
-        my $req_url = join(
-            '',
-            $scheme,
-            '://',
-            (defined($username) && defined($password) ? "${username}:${password}@" : ()),
-            "$host:${port}${path_query}",
-        );
-        for my $cookie ($res->header('Set-Cookie')) {
-            # Do not use $args{url} as a url. Because the server may redirected.
-            $cookie_jar->add($req_url, $cookie);
-        }
-    }
-
     return $res;
 }
 
