@@ -4,7 +4,7 @@ use warnings;
 use base qw/Exporter/;
 use 5.008001;
 
-our $VERSION = '3.07';
+our $VERSION = '3.08';
 
 use Carp ();
 use Furl::ConnectionCache;
@@ -113,11 +113,12 @@ sub put {
 }
 
 sub delete {
-    my ( $self, $url, $headers ) = @_;
+    my ( $self, $url, $headers, $content ) = @_;
     $self->request(
         method  => 'DELETE',
         url     => $url,
-        headers => $headers
+        headers => $headers,
+        content => $content
     );
 }
 
@@ -307,6 +308,7 @@ sub request {
     # write request
     my $method = $args{method} || 'GET';
     my $connection_header = $self->{connection_header};
+    my $cookie_jar = $self->{cookie_jar};
     {
         my @headers = @{$self->{headers}};
         $connection_header = 'close'
@@ -330,6 +332,24 @@ sub request {
             push @headers, 'Authorization', 'Basic ' . MIME::Base64::encode_base64("${username}:${password}","");
         }
 
+        # set Cookie header
+        if (defined $cookie_jar) {
+            my $url;
+            if ($args{url}) {
+                $url = $args{url};
+            } else {
+                $url = join(
+                    '',
+                    $args{scheme},
+                    '://',
+                    $args{host},
+                    (exists($args{port}) ? ":$args{port}" : ()),
+                    exists($args{path_query}) ? $args{path_query} : '/',
+                );
+            }
+            push @headers, 'Cookie' => $cookie_jar->cookie_header($url);
+        }
+
         my $content       = $args{content};
         my $content_is_fh = 0;
         if(defined $content) {
@@ -364,9 +384,10 @@ sub request {
         }
 
         # finally, set Host header
-        push @headers, 'Host' => (($port == $default_port) ? $host : "$host:$port");
+        my $request_target = ($port == $default_port) ? $host : "$host:$port";
+        push @headers, 'Host' => $request_target;
 
-        my $request_uri = $proxy ? "$scheme://$host:$port$path_query" : $path_query;
+        my $request_uri = $proxy && $scheme eq 'http' ? "$scheme://$request_target$path_query" : $path_query;
 
         my $p = "$method $request_uri HTTP/1.1\015\012";
         for (my $i = 0; $i < @headers; $i += 2) {
@@ -536,6 +557,22 @@ sub request {
     # since it might be reused in the upcoming recursive call
     undef $sock;
 
+    # process 'Set-Cookie' header.
+    if (defined $cookie_jar) {
+        my $req_url = join(
+            '',
+            $scheme,
+            '://',
+            (defined($username) && defined($password) ? "${username}:${password}@" : ()),
+            "$host:${port}${path_query}",
+        );
+        my $cookies = $res_headers->{'set-cookie'};
+        $cookies = [$cookies] if !ref$cookies;
+        for my $cookie (@$cookies) {
+            $cookie_jar->add($req_url, $cookie);
+        }
+    }
+
     if ($do_redirect) {
         my $location = $special_headers->{location};
         unless ($location =~ m{^[a-z0-9]+://}) {
